@@ -650,7 +650,7 @@ class Simulation(ABC):
 
         # copy model files to simulation directory, ignoring __pycache__ files
         direc_path = sim.main_path + name + "_copy"
-        shutil.copytree(os.getcwd(), direc_path, ignore=shutil.ignore_patterns("__pycache__"))
+        shutil.copytree(os.getcwd(), direc_path, ignore=shutil.ignore_patterns("__pycache__", os.path.basename(output_dir[:-1])))
 
         # set up the simulation agents and run the simulation
         sim.full_setup()
